@@ -39,11 +39,13 @@ func (t *DefaultRSSTranslator) Translate(feed interface{}) (*Feed, error) {
 	result.Description = t.translateFeedDescription(rss)
 	result.Link = t.translateFeedLink(rss)
 	result.FeedLink = t.translateFeedFeedLink(rss)
+	result.Links = t.translateFeedLinks(rss)
 	result.Updated = t.translateFeedUpdated(rss)
 	result.UpdatedParsed = t.translateFeedUpdatedParsed(rss)
 	result.Published = t.translateFeedPublished(rss)
 	result.PublishedParsed = t.translateFeedPublishedParsed(rss)
 	result.Author = t.translateFeedAuthor(rss)
+	result.Authors = t.translateFeedAuthors(rss)
 	result.Language = t.translateFeedLanguage(rss)
 	result.Image = t.translateFeedImage(rss)
 	result.Copyright = t.translateFeedCopyright(rss)
@@ -64,9 +66,11 @@ func (t *DefaultRSSTranslator) translateFeedItem(rssItem *rss.Item) (item *Item)
 	item.Description = t.translateItemDescription(rssItem)
 	item.Content = t.translateItemContent(rssItem)
 	item.Link = t.translateItemLink(rssItem)
+	item.Links = t.translateItemLinks(rssItem)
 	item.Published = t.translateItemPublished(rssItem)
 	item.PublishedParsed = t.translateItemPublishedParsed(rssItem)
 	item.Author = t.translateItemAuthor(rssItem)
+	item.Authors = t.translateItemAuthors(rssItem)
 	item.GUID = t.translateItemGUID(rssItem)
 	item.Image = t.translateItemImage(rssItem)
 	item.Categories = t.translateItemCategories(rssItem)
@@ -113,6 +117,26 @@ func (t *DefaultRSSTranslator) translateFeedFeedLink(rss *rss.Feed) (link string
 	return
 }
 
+func (t *DefaultRSSTranslator) translateFeedLinks(rss *rss.Feed) (links []string) {
+	if rss.Link != "" {
+		links = append(links, rss.Link)
+	}
+	if rss.ITunesExt != nil && rss.ITunesExt.Subtitle != "" {
+		links = append(links, rss.ITunesExt.Subtitle)
+	}
+	atomExtensions := t.extensionsForKeys([]string{"atom", "atom10", "atom03"}, rss.Extensions)
+	for _, ex := range atomExtensions {
+		if lks, ok := ex["link"]; ok {
+			for _, l := range lks {
+				if l.Attrs["rel"] == "" || l.Attrs["rel"] == "alternate" || l.Attrs["rel"] == "self" {
+					links = append(links, l.Attrs["href"])
+				}
+			}
+		}
+	}
+	return
+}
+
 func (t *DefaultRSSTranslator) translateFeedUpdated(rss *rss.Feed) (updated string) {
 	if rss.LastBuildDate != "" {
 		updated = rss.LastBuildDate
@@ -175,6 +199,13 @@ func (t *DefaultRSSTranslator) translateFeedAuthor(rss *rss.Feed) (author *Perso
 	return
 }
 
+func (t *DefaultRSSTranslator) translateFeedAuthors(rss *rss.Feed) (authors []*Person) {
+	if author := t.translateFeedAuthor(rss); author != nil {
+		authors = []*Person{author}
+	}
+	return
+}
+
 func (t *DefaultRSSTranslator) translateFeedLanguage(rss *rss.Feed) (language string) {
 	if rss.Language != "" {
 		language = rss.Language
@@ -279,6 +310,12 @@ func (t *DefaultRSSTranslator) translateItemContent(rssItem *rss.Item) (content
 func (t *DefaultRSSTranslator) translateItemLink(rssItem *rss.Item) (link string) {
 	return rssItem.Link
 }
+func (t *DefaultRSSTranslator) translateItemLinks(rssItem *rss.Item) (links []string) {
+	if rssItem.Link == "" {
+		return nil
+	}
+	return []string{rssItem.Link}
+}
 
 func (t *DefaultRSSTranslator) translateItemUpdated(rssItem *rss.Item) (updated string) {
 	if rssItem.DublinCoreExt != nil && rssItem.DublinCoreExt.Date != nil {
@@ -347,6 +384,14 @@ func (t *DefaultRSSTranslator) translateItemAuthor(rssItem *rss.Item) (author *P
 	return
 }
 
+func (t *DefaultRSSTranslator) translateItemAuthors(rssItem *rss.Item) (authors []*Person) {
+
+	if author := t.translateItemAuthor(rssItem); author != nil {
+		authors = []*Person{author}
+	}
+	return
+}
+
 func (t *DefaultRSSTranslator) translateItemGUID(rssItem *rss.Item) (guid string) {
 	if rssItem.GUID != nil {
 		guid = rssItem.GUID.Value
@@ -449,9 +494,11 @@ func (t *DefaultAtomTranslator) Translate(feed interface{}) (*Feed, error) {
 	result.Description = t.translateFeedDescription(atom)
 	result.Link = t.translateFeedLink(atom)
 	result.FeedLink = t.translateFeedFeedLink(atom)
+	result.Links = t.translateFeedLinks(atom)
 	result.Updated = t.translateFeedUpdated(atom)
 	result.UpdatedParsed = t.translateFeedUpdatedParsed(atom)
 	result.Author = t.translateFeedAuthor(atom)
+	result.Authors = t.translateFeedAuthors(atom)
 	result.Language = t.translateFeedLanguage(atom)
 	result.Image = t.translateFeedImage(atom)
 	result.Copyright = t.translateFeedCopyright(atom)
@@ -470,11 +517,13 @@ func (t *DefaultAtomTranslator) translateFeedItem(entry *atom.Entry) (item *Item
 	item.Description = t.translateItemDescription(entry)
 	item.Content = t.translateItemContent(entry)
 	item.Link = t.translateItemLink(entry)
+	item.Links = t.translateItemLinks(entry)
 	item.Updated = t.translateItemUpdated(entry)
 	item.UpdatedParsed = t.translateItemUpdatedParsed(entry)
 	item.Published = t.translateItemPublished(entry)
 	item.PublishedParsed = t.translateItemPublishedParsed(entry)
 	item.Author = t.translateItemAuthor(entry)
+	item.Authors = t.translateItemAuthors(entry)
 	item.GUID = t.translateItemGUID(entry)
 	item.Image = t.translateItemImage(entry)
 	item.Categories = t.translateItemCategories(entry)
@@ -507,6 +556,15 @@ func (t *DefaultAtomTranslator) translateFeedFeedLink(atom *atom.Feed) (link str
 	return
 }
 
+func (t *DefaultAtomTranslator) translateFeedLinks(atom *atom.Feed) (links []string) {
+	for _, l := range atom.Links {
+		if l.Rel == "" || l.Rel == "alternate" || l.Rel == "self" {
+			links = append(links, l.Href)
+		}
+	}
+	return
+}
+
 func (t *DefaultAtomTranslator) translateFeedUpdated(atom *atom.Feed) (updated string) {
 	return atom.Updated
 }
@@ -526,6 +584,22 @@ func (t *DefaultAtomTranslator) translateFeedAuthor(atom *atom.Feed) (author *Pe
 	return
 }
 
+func (t *DefaultAtomTranslator) translateFeedAuthors(atom *atom.Feed) (authors []*Person) {
+
+	if atom.Authors != nil {
+		authors = []*Person{}
+
+		for _, a := range atom.Authors {
+			authors = append(authors, &Person{
+				Name:  a.Name,
+				Email: a.Email,
+			})
+		}
+	}
+
+	return
+}
+
 func (t *DefaultAtomTranslator) translateFeedLanguage(atom *atom.Feed) (language string) {
 	return atom.Language
 }
@@ -600,6 +674,15 @@ func (t *DefaultAtomTranslator) translateItemLink(entry *atom.Entry) (link strin
 	return
 }
 
+func (t *DefaultAtomTranslator) translateItemLinks(entry *atom.Entry) (links []string) {
+	for _, l := range entry.Links {
+		if l.Rel == "" || l.Rel == "alternate" || l.Rel == "self" {
+			links = append(links, l.Href)
+		}
+	}
+	return
+}
+
 func (t *DefaultAtomTranslator) translateItemUpdated(entry *atom.Entry) (updated string) {
 	return entry.Updated
 }
@@ -608,12 +691,20 @@ func (t *DefaultAtomTranslator) translateItemUpdatedParsed(entry *atom.Entry) (u
 	return entry.UpdatedParsed
 }
 
-func (t *DefaultAtomTranslator) translateItemPublished(entry *atom.Entry) (updated string) {
-	return entry.Published
+func (t *DefaultAtomTranslator) translateItemPublished(entry *atom.Entry) (published string) {
+	published = entry.Published
+	if published == "" {
+		published = entry.Updated
+	}
+	return
 }
 
-func (t *DefaultAtomTranslator) translateItemPublishedParsed(entry *atom.Entry) (updated *time.Time) {
-	return entry.PublishedParsed
+func (t *DefaultAtomTranslator) translateItemPublishedParsed(entry *atom.Entry) (published *time.Time) {
+	published = entry.PublishedParsed
+	if published == nil {
+		published = entry.UpdatedParsed
+	}
+	return
 }
 
 func (t *DefaultAtomTranslator) translateItemAuthor(entry *atom.Entry) (author *Person) {
@@ -626,6 +717,19 @@ func (t *DefaultAtomTranslator) translateItemAuthor(entry *atom.Entry) (author *
 	return
 }
 
+func (t *DefaultAtomTranslator) translateItemAuthors(entry *atom.Entry) (authors []*Person) {
+	if entry.Authors != nil {
+		authors = []*Person{}
+		for _, a := range entry.Authors {
+			authors = append(authors, &Person{
+				Name:  a.Name,
+				Email: a.Email,
+			})
+		}
+	}
+	return
+}
+
 func (t *DefaultAtomTranslator) translateItemGUID(entry *atom.Entry) (guid string) {
 	return entry.ID
 }
@@ -707,9 +811,12 @@ func (t *DefaultJSONTranslator) Translate(feed interface{}) (*Feed, error) {
 	result.Title = t.translateFeedTitle(json)
 	result.Link = t.translateFeedLink(json)
 	result.FeedLink = t.translateFeedFeedLink(json)
+	result.Links = t.translateFeedLinks(json)
 	result.Description = t.translateFeedDescription(json)
 	result.Image = t.translateFeedImage(json)
 	result.Author = t.translateFeedAuthor(json)
+	result.Authors = t.translateFeedAuthors(json)
+	result.Language = t.translateFeedLanguage(json)
 	result.Items = t.translateFeedItems(json)
 	result.Updated = t.translateFeedUpdated(json)
 	result.UpdatedParsed = t.translateFeedUpdatedParsed(json)
@@ -729,6 +836,7 @@ func (t *DefaultJSONTranslator) translateFeedItem(jsonItem *json.Item) (item *It
 	item = &Item{}
 	item.GUID = t.translateItemGUID(jsonItem)
 	item.Link = t.translateItemLink(jsonItem)
+	item.Links = t.translateItemLinks(jsonItem)
 	item.Title = t.translateItemTitle(jsonItem)
 	item.Content = t.translateItemContent(jsonItem)
 	item.Description = t.translateItemDescription(jsonItem)
@@ -738,6 +846,7 @@ func (t *DefaultJSONTranslator) translateFeedItem(jsonItem *json.Item) (item *It
 	item.Updated = t.translateItemUpdated(jsonItem)
 	item.UpdatedParsed = t.translateItemUpdatedParsed(jsonItem)
 	item.Author = t.translateItemAuthor(jsonItem)
+	item.Authors = t.translateItemAuthors(jsonItem)
 	item.Categories = t.translateItemCategories(jsonItem)
 	item.Enclosures = t.translateItemEnclosures(jsonItem)
 	// TODO ExternalURL is missing in global Feed
@@ -770,6 +879,16 @@ func (t *DefaultJSONTranslator) translateFeedFeedLink(json *json.Feed) (link str
 	return
 }
 
+func (t *DefaultJSONTranslator) translateFeedLinks(json *json.Feed) (links []string) {
+	if json.HomePageURL != "" {
+		links = append(links, json.HomePageURL)
+	}
+	if json.FeedURL != "" {
+		links = append(links, json.FeedURL)
+	}
+	return
+}
+
 func (t *DefaultJSONTranslator) translateFeedUpdated(json *json.Feed) (updated string) {
 	if len(json.Items) > 0 {
 		updated = json.Items[0].DateModified
@@ -816,6 +935,31 @@ func (t *DefaultJSONTranslator) translateFeedAuthor(json *json.Feed) (author *Pe
 	return
 }
 
+func (t *DefaultJSONTranslator) translateFeedAuthors(json *json.Feed) (authors []*Person) {
+
+	if json.Authors != nil {
+		authors = []*Person{}
+		for _, a := range json.Authors {
+			name, address := shared.ParseNameAddress(a.Name)
+			author := &Person{}
+			author.Name = name
+			author.Email = address
+
+			authors = append(authors, author)
+		}
+	} else if author := t.translateFeedAuthor(json); author != nil {
+		authors = []*Person{author}
+	}
+	// Author.URL is missing in global feed
+	// Author.Avatar is missing in global feed
+	return
+}
+
+func (t *DefaultJSONTranslator) translateFeedLanguage(json *json.Feed) (language string) {
+	language = json.Language
+	return
+}
+
 func (t *DefaultJSONTranslator) translateFeedImage(json *json.Feed) (image *Image) {
 	// Using the Icon rather than the image
 	// icon (optional, string) is the URL of an image for the feed suitable to be used in a timeline. It should be square and relatively large — such as 512 x 512
@@ -861,6 +1005,16 @@ func (t *DefaultJSONTranslator) translateItemLink(jsonItem *json.Item) (link str
 	return jsonItem.URL
 }
 
+func (t *DefaultJSONTranslator) translateItemLinks(jsonItem *json.Item) (links []string) {
+	if jsonItem.URL != "" {
+		links = append(links, jsonItem.URL)
+	}
+	if jsonItem.ExternalURL != "" {
+		links = append(links, jsonItem.ExternalURL)
+	}
+	return
+}
+
 func (t *DefaultJSONTranslator) translateItemUpdated(jsonItem *json.Item) (updated string) {
 	if jsonItem.DateModified != "" {
 		updated = jsonItem.DateModified
@@ -907,6 +1061,26 @@ func (t *DefaultJSONTranslator) translateItemAuthor(jsonItem *json.Item) (author
 	return
 }
 
+func (t *DefaultJSONTranslator) translateItemAuthors(jsonItem *json.Item) (authors []*Person) {
+
+	if jsonItem.Authors != nil {
+		authors = []*Person{}
+		for _, a := range jsonItem.Authors {
+			name, address := shared.ParseNameAddress(a.Name)
+			author := &Person{}
+			author.Name = name
+			author.Email = address
+
+			authors = append(authors, author)
+		}
+	} else if author := t.translateItemAuthor(jsonItem); author != nil {
+		authors = []*Person{author}
+	}
+	// Author.URL is missing in global feed
+	// Author.Avatar is missing in global feed
+	return
+}
+
 func (t *DefaultJSONTranslator) translateItemGUID(jsonItem *json.Item) (guid string) {
 	if jsonItem.ID != "" {
 		guid = jsonItem.ID
